@@ -15,8 +15,7 @@
 #endif
 
 #include <string.h>
-#include <libintl.h>
-
+#include <glib/gi18n.h>
 #include <libbonobo.h>
 #include <libgnomeui/libgnomeui.h> 
 #include <libgnomevfs/gnome-vfs.h>
@@ -35,6 +34,11 @@
 
 #define CLEAN_WCAP 0
 
+#if SUNONE_DEBUG
+extern gchar *verbose_debug;
+extern gint	debug_level;
+#endif
+
 static EDataCalFactory *calendar_factory = NULL;
 char *evolution_dir;
 static BonoboGenericFactory *component_factory = NULL;
@@ -174,7 +178,6 @@ main (int argc, char *argv[])
 	camel_init (evolution_dir, FALSE);
 #endif
 	e_passwords_init ();
-	sunone_message_init ();
 
 #if CLEAN_WCAP
 	/* remove trash esources if possible */	
@@ -196,16 +199,18 @@ main (int argc, char *argv[])
 
 	/* run the application */
 	g_message ("Evolution-jescs up and running!\n");
-	if (getenv ("EVOLUTION_JESCS_VERBOSE_DEBUG")) {
-                /* Redirect stderr to stdout and make it line-buffered
-                 * rather than block-buffered, for ease of debug
-                 * redirection.
-                 */
-                dup2 (STDOUT_FILENO, STDERR_FILENO);
-                setvbuf (stdout, NULL, _IOLBF, 0);
-                setvbuf (stderr, NULL, _IOLBF, 0);
-                printf ("EVOLUTION_JESCS_VERBOSE_DEBUG=1\n");
-        }
+	verbose_debug = getenv ("EVOLUTION_JESCS_VERBOSE_DEBUG");
+	if (verbose_debug) {
+		/* Redirect stderr to stdout and make it line-buffered
+		 * rather than block-buffered, for ease of debug
+		 * redirection.
+		 */
+		debug_level = atoi (verbose_debug);
+		dup2 (STDOUT_FILENO, STDERR_FILENO);
+		setvbuf (stdout, NULL, _IOLBF, 0);
+		setvbuf (stderr, NULL, _IOLBF, 0);
+		printf ("EVOLUTION_JESCS_VERBOSE_DEBUG=%d\n", debug_level);
+	}
 
 	bonobo_main ();
 
