@@ -89,7 +89,8 @@ finalize (GObject *object)
 
 static GNOME_Evolution_ComponentView
 impl_createView (PortableServer_Servant servant,
-			GNOME_Evolution_ShellView parent,
+			const GNOME_Evolution_ShellView parent,
+			const CORBA_boolean select_item,
 			CORBA_Environment *ev)
 {
 	SunOneComponent *component = SUNONE_COMPONENT (bonobo_object_from_servant (servant));
@@ -234,6 +235,7 @@ sunone_component_init (SunOneComponent *component)
 	g_signal_connect (priv->config_listener, "sunone_account_removed",
 			  G_CALLBACK (config_listener_account_removed),
 			  component);
+	sunone_config_listener_construct_account (priv->config_listener);
 }
 
 BONOBO_TYPE_FUNC_FULL (SunOneComponent, GNOME_Evolution_Component, PARENT_TYPE, sunone_component)
